package betterquesting.api2.client.gui.panels.bars;

import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.controls.IValueIO;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import java.util.List;
import net.minecraft.util.MathHelper;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_panels_bars.jar:betterquesting/api2/client/gui/panels/bars/PanelHBarFill.class */
public class PanelHBarFill implements IBarFill {
    private final IGuiRect transform;
    private IValueIO<Float> fillDriver;
    private boolean enabled = true;
    private boolean flipBar = false;
    private IGuiColor color = new GuiColorStatic(-1);
    private IGuiTexture texBack = PresetTexture.METER_H_0.getTexture();
    private IGuiTexture texFill = PresetTexture.METER_H_1.getTexture();

    @Override // betterquesting.api2.client.gui.panels.bars.IBarFill
    public /* bridge */ /* synthetic */ IBarFill setFillDriver(IValueIO iValueIO) {
        return setFillDriver((IValueIO<Float>) iValueIO);
    }

    public PanelHBarFill(IGuiRect rect) {
        this.transform = rect;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IBarFill
    public PanelHBarFill setFillDriver(IValueIO<Float> driver) {
        this.fillDriver = driver;
        return this;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IBarFill
    public PanelHBarFill setFlipped(boolean flipped) {
        this.flipBar = flipped;
        return this;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IBarFill
    public PanelHBarFill setFillColor(IGuiColor color) {
        this.color = color;
        return this;
    }

    @Override // betterquesting.api2.client.gui.panels.bars.IBarFill
    public PanelHBarFill setBarTexture(IGuiTexture back, IGuiTexture front) {
        this.texBack = back;
        this.texFill = front;
        return this;
    }

    public void initPanel() {
    }

    public void setEnabled(boolean state) {
        this.enabled = state;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public IGuiRect getTransform() {
        return this.transform;
    }

    public void drawPanel(int mx, int my, float partialTick) {
        IGuiRect bounds = getTransform();
        GL11.glPushMatrix();
        GL11.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
        if (this.texBack != null) {
            this.texBack.drawTexture(bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight(), 0.0f, partialTick);
        }
        float f = MathHelper.func_76131_a(((Float) this.fillDriver.readValue()).floatValue(), 0.0f, 1.0f);
        if (this.flipBar) {
            RenderUtils.startScissor(new GuiRectangle(bounds.getX() + ((int) (bounds.getWidth() - (bounds.getWidth() * f))), bounds.getY(), (int) (bounds.getWidth() * f), bounds.getHeight(), 0));
        } else {
            RenderUtils.startScissor(new GuiRectangle(bounds.getX(), bounds.getY(), (int) (bounds.getWidth() * f), bounds.getHeight(), 0));
        }
        if (this.texFill != null) {
            this.texFill.drawTexture(bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight(), 0.0f, partialTick, this.color);
        }
        RenderUtils.endScissor();
        GL11.glPopMatrix();
    }

    public boolean onMouseClick(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseRelease(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseScroll(int mx, int my, int scroll) {
        return false;
    }

    public boolean onKeyTyped(char c, int keycode) {
        return false;
    }

    public List<String> getTooltip(int mx, int my) {
        return null;
    }
}
